# SessyPy
A python wrapper for Sessy's local REST api.

Installation
============

Automatic installation
----------------------
Install the package via PyPI (not available yet):
```
pip install sessypy
```

Manual installation
-------------------
```
git clone https://github.com/PimDoos/sessypy
pip install ./sessypy
```
